


LILO(8)							  LILO(8)


NAME
       lilo - install boot loader

SYNOPSIS
       Main function:

	/sbin/lilo - install boot loader

       Auxiliary uses:

	/sbin/lilo -q - query map
	/sbin/lilo -R - set default command line for next reboot
	/sbin/lilo -I - inquire path name of current kernel
	/sbin/lilo {-u|-U} - uninstall lilo

DESCRIPTION
       lilo  installs  a  boot loader that will be activated next
       time you boot.  It has lots of options.


       -v     Increase verbosity. Giving one or more  -v  options
	      will make lilo more verbose.

       -q     List  the currently mapped files.	 lilo maintains a
	      file, by default /boot/map, containing the name and
	      location	of  the	 kernel(s)  to boot.  This option
	      will list the names therein.

       -m map-file
	      Use specified map file instead of the default.

       -C config-file
	      lilo reads its instructions about what files to map
	      from  its	 config	 file, by default /etc/lilo.conf.
	      This option can be used to  specify  a  non-default
	      config file.

       -d delay
	      If  you  have  specified several kernels, and press
	      Shift at boot-time, the boot  loader  will  present
	      you  with a choice of which system to boot. After a
	      timeout period the first	kernel	in  the	 list  is
	      booted.  This option specifies the timeout delay in
	      deciseconds.

       -D label
	      Use the kernel with the given label, instead of the
	      first  one  in  the  list, as the default kernel to
	      boot.

       -r root-directory
	      Before doing anything else,  do  a  chroot  to  the
	      indicated	 directory.  Used  for	repairing a setup
	      from a boot floppy.



			   28 July 1995				1





LILO(8)							  LILO(8)


       -t     Test only. Do not really write a new boot sector or
	      map  file.   Use	together with -v to find out what
	      lilo is about to do.

       -c     Enable  map  compaction.	This  will   merge   read
	      requests from adjacent sectors. Speeds up the boot-
	      ing (especially from floppy).

       -f disk-tab
	      Specify disk geometry parameter file. (The  default
	      is /etc/disktab.)

       -i boot-sector
	      Specify  a  file to be used as the new boot sector.
	      (The default is /boot/boot.b.)

       -l     Generate linear sector addresses	instead	 of  sec-
	      tor/head/cylinder addresses.

       -P {fix|ignore}
	      Fix  (or	ignore) `corrupt' partition tables, i.e.,
	      partition tables with linear and sector/head/cylin-
	      der addresses that do not correspond.

       -s save-file
	      When  lilo overwrites the boot sector, it preserves
	      the  old	 contents   in	 a   file,   by	  default
	      /boot/boot.NNNN  where  NNNN depends on the device.
	      This option specifies an alternate  save	file  for
	      the  boot sector. (Or, together with the -u option,
	      specifies from where to restore the boot sector.)

       -S save-file
	      Normally, lilo will not overwrite an existing  save
	      file.   This   options  says  that  overwriting  is
	      allowed.

       -u device-name
	      Uninstall lilo, by copying the  saved  boot  sector
	      back. A time-stamp is checked.

       -U device-name
	      Idem, but do not check the time-stamp.

       -R command line
	      This  option  sets the default command for the boot
	      loader the next time it executes. The  boot  loader
	      will then erase this line: this is a once-only com-
	      mand. It is typically used in reboot scripts,  just
	      before calling `shutdown -r'.

       -I label
	      The label of the running kernel can be found in the
	      environment variable BOOT_IMAGE after startup. This



			   28 July 1995				2





LILO(8)							  LILO(8)


	      command  will  print the corresponding path name on
	      stdout.

       -V     Print version number.


       The above command line options correspond to the key words
       in the config file indicated below.

	      -b bootdev      boot=bootdev
	      -c	      compact
	      -d dsec	      delay=dsec
	      -D label	      default=label
	      -i bootsector   install=bootsector
	      -f file	      disktab=file
	      -l	      linear
	      -m mapfile      map=mapfile
	      -P fix	      fix-table
	      -P ignore	      ignore-table
	      -s file	      backup=file
	      -S file	      force-backup=file
	      -v	      verbose=level

SEE ALSO
       lilo.conf(5).
       The lilo distribution comes with very extensive documenta-
       tion.

AUTHOR
       Werner Almesberger (almesber@bernina.ethz.ch).



























			   28 July 1995				3


